==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Limpar registo</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Tem a certeza de que deseja limpar o registo?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dias</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mês</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meses</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportar</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgente</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notificação</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuração</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Início sessão</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super crítico</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Vestígio</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXTO (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>A exportar...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportação bem sucedida</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Falha ao exportar</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportar ficheiro</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Período:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista de aplicações:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilizador:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Ação:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registo do arranque</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Registo do encerrar</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Registo do iniciar sessão</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuração</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgente</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notificação</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Vestígio</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super crítico</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>O ficheiro de registo está vazio</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visualizador de Registos</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>O Visualizador de Registos é uma ferramenta útil para visualizar os registos do sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nenhum resultado correspondente à pesquisa</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nível</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Processo</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data e Hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Origem</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo de evento</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Processo:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data e Hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informação:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilizador:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data e Hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Arrancar-Encerrar</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registo dnf</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostrar no gestor de ficheiros</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Limpar registo</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Tem a certeza de que deseja limpar o registo?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dias</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 semana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mês</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 meses</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgente</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notificação</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuração</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Início sessão</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Encerrar</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super crítico</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Vestígio</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXTO (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>A exportar...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportação bem sucedida</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Falha ao exportar</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exportar ficheiro</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Período:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estado:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipo de evento:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilizador:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Ação:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registo do arranque</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Registo do encerrar</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Registo do iniciar sessão</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuração</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgente</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítico</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Notificação</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Vestígio</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Super crítico</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>O ficheiro de registo está vazio</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visualizador de Registos</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>O Visualizador de Registos é uma ferramenta útil para visualizar os registos do sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Nenhum resultado correspondente à pesquisa</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nível</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Processo</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data e Hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilizador</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Origem</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipo de evento</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome de utilizador</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Processo:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data e Hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informação:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Utilizador:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Data de modificação</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data e Hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Arranque</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Arrancar-Encerrar</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registo dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Outro registo</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Ficheiro personalizado</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Não tem permissão para o ver</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Intervalo de atualização</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 seg</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 mins</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Sem atualização</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Exportar tudo</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Atualizar agora</translation>
    </message>
</context>
</TS>
